@@ -4,7 +4,7 @@ use warnings;
 package UR::DataSource::RDBMS::Table;
 
 use UR;
-our $VERSION = "0.37"; # UR $VERSION;
+our $VERSION = "0.38"; # UR $VERSION;
 
 UR::Object::Type->define(
     class_name => 'UR::DataSource::RDBMS::Table',
@@ -76,7 +76,10 @@ sub primary_key_constraint_columns {
 
     my $pk_class = $self->_pk_constraint_class;
     my @pks = $pk_class->get(data_source => $self->data_source, table_name  => $self->table_name);
-    return sort { $a->rank <=> $b->rank } @pks;
+    my @pks_with_rank = map { [ $_->rank, $_ ] } @pks;
+    return map { $_->[1] }
+           sort { $a->[0] <=> $b->[0] }
+           @pks_with_rank;
 }
 
 
