@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use UR;
-our $VERSION = "0.37"; # UR $VERSION;
+our $VERSION = "0.38"; # UR $VERSION;
 use Data::Dumper;
 
 class UR::Object::Command::FetchAndDo {
@@ -191,7 +191,9 @@ sub _subject_class_filterable_properties {
     my %props = map { $_->property_name => $_ }
                     $self->subject_class->property_metas;
 
-    return sort { $a->property_name cmp $b->property_name }
+    return map { $_->[1] }                   # These maps are to get around a bug in perl 5.8
+           sort { $a->[0] cmp $b->[0] }      # sort involving methdo calls inside the sort sub that
+           map { [ $_->property_name, $_ ] } # might do sorts of their own
            grep { substr($_->property_name, 0, 1) ne '_' }  # Skip 'private' properties starting with '_'
            grep { ! $_->data_type or index($_->data_type, '::') == -1 }  # Can't filter object-type properties from a lister, right?
            values %props;
